@@ -129,7 +129,8 @@ class  QamTestCase(unittest.TestCase):
                          vhost=self.amqp_vhost,
                          server_id='testqamserver',
                          client_id='testqamclient1',
-                         serializer='json'
+                         serializer='json',
+                         ssl=False
                          )
 
         for i in range(10):
